==> everycomp-1.20-2.9.10-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/mcaw/MacawFurnitureModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.mcaw;

import net.kikoz.mcwfurnitures.objects.*;
import net.kikoz.mcwfurnitures.objects.cabinets.Cabinet;
import net.kikoz.mcwfurnitures.objects.cabinets.CabinetHinge;
import net.kikoz.mcwfurnitures.objects.chairs.ModernChair;
import net.kikoz.mcwfurnitures.objects.chairs.StripedChair;
import net.kikoz.mcwfurnitures.objects.counters.Counter;
import net.kikoz.mcwfurnitures.objects.counters.CupboardCounter;
import net.kikoz.mcwfurnitures.objects.counters.StorageCounter;
import net.mehvahdjukaar.every_compat.modules.macaw.MacawFurnitureModuleAbstract;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.minecraft.class_2248;

//See MacawFurnitureAbstractModule's SUPPORTED VERSION
public class MacawFurnitureModule extends MacawFurnitureModuleAbstract {

    public MacawFurnitureModule(String modId) {
        super(modId);
    }

    @Override
    public class_2248 newCabinet(WoodType woodType) {
        return new Cabinet(copyStandardProperties());
    }

    @Override
    public class_2248 newCabinetHinge(WoodType woodType) {
        return new CabinetHinge(copyStandardProperties());
    }

    @Override
    public class_2248 newWideFurniture(WoodType woodType) {
        return new WideFurniture(copyStandardProperties());
    }

    @Override
    public class_2248 newTallFurniture(WoodType woodType) {
        return new TallFurniture(copyStandardProperties());
    }

    @Override
    public class_2248 newTallFurnitureHinge(WoodType woodType) {
        return new TallFurnitureHinge(copyStandardProperties());
    }

    @Override
    public class_2248 newDesk(WoodType woodType) {
        return new Desk(copyStandardProperties());
    }

    @Override
    public class_2248 newTable(WoodType woodType) {
        return new Table(copyStandardProperties());
    }

    @Override
    public class_2248 newTableHitbox(WoodType woodType) {
        return new TableHitbox(copyStandardProperties());
    }

    @Override
    public class_2248 newStripedChair(WoodType woodType) {
        return new StripedChair(copyStandardProperties());
    }

    @Override
    public class_2248 newModernChair(WoodType woodType) {
        return new ModernChair(copyStandardProperties());
    }

    @Override
    public class_2248 newChair(WoodType woodType) {
        return new Chair(copyStandardProperties());
    }

    @Override
    public class_2248 newCounter(WoodType woodType) {
        return new Counter(copyStandardProperties());
    }

    @Override
    public class_2248 newStorageCounter(WoodType woodType) {
        return new StorageCounter(copyStandardProperties());
    }

    @Override
    public class_2248 newCupboardCounter(WoodType woodType) {
        return new CupboardCounter(copyStandardProperties());
    }
}

==> everycomp-1.21-2.11.17-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/fabric/mcaw/MacawFurnitureModule.java <==
package net.mehvahdjukaar.every_compat.modules.fabric.mcaw;

import net.kikoz.mcwfurnitures.objects.*;
import net.kikoz.mcwfurnitures.objects.cabinets.Cabinet;
import net.kikoz.mcwfurnitures.objects.cabinets.CabinetHinge;
import net.kikoz.mcwfurnitures.objects.chairs.ModernChair;
import net.kikoz.mcwfurnitures.objects.chairs.StripedChair;
import net.kikoz.mcwfurnitures.objects.counters.Counter;
import net.kikoz.mcwfurnitures.objects.counters.CupboardCounter;
import net.kikoz.mcwfurnitures.objects.counters.StorageCounter;
import net.mehvahdjukaar.every_compat.modules.macaw.MacawFurnitureAbstractModule;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.minecraft.class_2248;

//See MacawFurnitureAbstractModule's SUPPORTED VERSION
public class MacawFurnitureModule extends MacawFurnitureAbstractModule {

    public MacawFurnitureModule(String modId) {
        super(modId);
    }

    @Override
    public class_2248 newCabinet(WoodType woodType) {
        return new Cabinet(copyStandardProperties());
    }

    @Override
    public class_2248 newCabinetHinge(WoodType woodType) {
        return new CabinetHinge(copyStandardProperties());
    }

    @Override
    public class_2248 newWideFurniture(WoodType woodType) {
        return new WideFurniture(copyStandardProperties());
    }

    @Override
    public class_2248 newTallFurniture(WoodType woodType) {
        return new TallFurniture(copyStandardProperties());
    }

    @Override
    public class_2248 newTallFurnitureHinge(WoodType woodType) {
        return new TallFurnitureHinge(copyStandardProperties());
    }

    @Override
    public class_2248 newDesk(WoodType woodType) {
        return new Desk(copyStandardProperties());
    }

    @Override
    public class_2248 newTable(WoodType woodType) {
        return new Table(copyStandardProperties());
    }

    @Override
    public class_2248 newTableHitbox(WoodType woodType) {
        return new TableHitbox(copyStandardProperties());
    }

    @Override
    public class_2248 newStripedChair(WoodType woodType) {
        return new StripedChair(copyStandardProperties());
    }

    @Override
    public class_2248 newModernChair(WoodType woodType) {
        return new ModernChair(copyStandardProperties());
    }

    @Override
    public class_2248 newChair(WoodType woodType) {
        return new Chair(copyStandardProperties());
    }

    @Override
    public class_2248 newCounter(WoodType woodType) {
        return new Counter(copyStandardProperties());
    }

    @Override
    public class_2248 newStorageCounter(WoodType woodType) {
        return new StorageCounter(copyStandardProperties());
    }

    @Override
    public class_2248 newCupboardCounter(WoodType woodType) {
        return new CupboardCounter(copyStandardProperties());
    }
}
